[DTrace-devel] [PATCH 1/5] Change use of dtrace_probe_iter()

eugene.loh at oracle.com eugene.loh at oracle.com
Thu Jun 11 14:29:37 PDT 2020


From: Eugene Loh <eugene.loh at oracle.com>

In DTrace v1, dtrace_probe_iter() was used to iterate over probes,
using dt_probe_iter() as a callback function.

In the current release, dtrace_probe_iter() will be used as an external
API, with dt_probe_iter() the "internal" (to libdtrace) interface.

Signed-off-by: Eugene Loh <eugene.loh at oracle.com>
---
 libdtrace/dt_probe.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/libdtrace/dt_probe.c b/libdtrace/dt_probe.c
index b6c79354..7fa6c341 100644
--- a/libdtrace/dt_probe.c
+++ b/libdtrace/dt_probe.c
@@ -989,14 +989,14 @@ dt_probe_info(dtrace_hdl_t *dtp, const dtrace_probedesc_t *pdp,
 	pd.id = DTRACE_IDNONE;
 
 	/*
 	 * Call dtrace_probe_iter() to find matching probes.  Our
 	 * dt_probe_desc() callback will produce the following results:
 	 *
 	 * m < 0 dtrace_probe_iter() found zero matches (or failed).
 	 * m > 0 dtrace_probe_iter() found more than one match.
 	 * m = 0 dtrace_probe_iter() found exactly one match.
 	 */
-	if ((m = dtrace_probe_iter(dtp, pdp, dt_probe_desc, &pd)) < 0)
+	if ((m = dt_probe_iter(dtp, pdp, NULL, dt_probe_desc, &pd)) < 0)
 		return NULL; /* dt_errno is set for us */
 
 	if ((pvp = dt_provider_lookup(dtp, pd.prv)) == NULL)
@@ -989,14 +989,14 @@ dt_probe_info(dtrace_hdl_t *dtp, const dtrace_probedesc_t *pdp,
 
 	/*
-	 * Call dtrace_probe_iter() to find matching probes.  Our
+	 * Call dt_probe_iter() to find matching probes.  Our
 	 * dt_probe_desc() callback will produce the following results:
 	 *
@@ -989,14 +989,14 @@ dt_probe_info(dtrace_hdl_t *dtp, const dtrace_probedesc_t *pdp,
 	 * dt_probe_desc() callback will produce the following results:
 	 *
-	 * m < 0 dtrace_probe_iter() found zero matches (or failed).
-	 * m > 0 dtrace_probe_iter() found more than one match.
-	 * m = 0 dtrace_probe_iter() found exactly one match.
+	 * m < 0 dt_probe_iter() found zero matches (or failed).
+	 * m > 0 dt_probe_iter() found more than one match.
+	 * m = 0 dt_probe_iter() found exactly one match.
 	 */
-- 
2.18.2




More information about the DTrace-devel mailing list